@@ -16,14 +16,8 @@
 
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file globus_job_manager.c Resource Allocation Job Manager
- *
- * CVS Information:
- * 
- * $Source$
- * $Date$
- * $Revision$
- * $Author$
+ * @file globus_gram_job_manager_config.c
+ * @brief Resource Allocation Job Manager Configuration
  */
 
 #include "globus_gram_job_manager.h"
@@ -122,7 +116,7 @@ globus_gram_job_manager_config_init(
         }
         rewind(fp);
 
-        newbuf = (char *) malloc(length+1);  /* dont free */
+        newbuf = (char *) malloc(length+1);  /* don't free */
         i = fread(newbuf, 1, length, fp);
         if (i < 0)
         {
